==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PobieraneSwiadczenie.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.RodzajOdbioruSwiadczenia;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PobieraneSwiadczenie extends GenericDPSObject {
    /**
     * POBIERANE_SWIADCZENIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * POBIERANE_SWIADCZENIE.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * POBIERANE_SWIADCZENIE.SWIADCZENIE_ZMIENIONE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieZmienioneId;

    /**
     * POBIERANE_SWIADCZENIE.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * POBIERANE_SWIADCZENIE.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * POBIERANE_SWIADCZENIE.DATA_ZMIANY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataZmiany;

    /**
     * POBIERANE_SWIADCZENIE.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * POBIERANE_SWIADCZENIE.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * POBIERANE_SWIADCZENIE.RODZAJ_ODBIORU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajOdbioruSwiadczenia rodzajOdbioru;

    /**
     * POBIERANE_SWIADCZENIE.INSTYTUCJA_DOPLACAJACA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long instytucjaDoplacajacaId;

    /**
     * POBIERANE_SWIADCZENIE.TERMIN_WYPLATY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long terminWyplatyId;

    /**
     * POBIERANE_SWIADCZENIE.KOD_SWIADCZENIA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kodSwiadczeniaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POBIERANE_SWIADCZENIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POBIERANE_SWIADCZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * POBIERANE_SWIADCZENIE.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.SWIADCZENIE_ZMIENIONE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieZmienioneId() {
        return swiadczenieZmienioneId;
    }

    /**
     * POBIERANE_SWIADCZENIE.SWIADCZENIE_ZMIENIONE_ID
     *
     * @param swiadczenieZmienioneId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieZmienioneId(Long swiadczenieZmienioneId) {
        this.swiadczenieZmienioneId = swiadczenieZmienioneId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * POBIERANE_SWIADCZENIE.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * POBIERANE_SWIADCZENIE.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.DATA_ZMIANY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataZmiany() {
        return dataZmiany;
    }

    /**
     * POBIERANE_SWIADCZENIE.DATA_ZMIANY
     *
     * @param dataZmiany
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataZmiany(Date dataZmiany) {
        this.dataZmiany = dataZmiany;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * POBIERANE_SWIADCZENIE.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * POBIERANE_SWIADCZENIE.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return POBIERANE_SWIADCZENIE.RODZAJ_ODBIORU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajOdbioruSwiadczenia getRodzajOdbioru() {
        return rodzajOdbioru;
    }

    /**
     * POBIERANE_SWIADCZENIE.RODZAJ_ODBIORU
     *
     * @param rodzajOdbioru
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajOdbioru(RodzajOdbioruSwiadczenia rodzajOdbioru) {
        this.rodzajOdbioru = rodzajOdbioru;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.INSTYTUCJA_DOPLACAJACA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInstytucjaDoplacajacaId() {
        return instytucjaDoplacajacaId;
    }

    /**
     * POBIERANE_SWIADCZENIE.INSTYTUCJA_DOPLACAJACA_ID
     *
     * @param instytucjaDoplacajacaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInstytucjaDoplacajacaId(Long instytucjaDoplacajacaId) {
        this.instytucjaDoplacajacaId = instytucjaDoplacajacaId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.TERMIN_WYPLATY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getTerminWyplatyId() {
        return terminWyplatyId;
    }

    /**
     * POBIERANE_SWIADCZENIE.TERMIN_WYPLATY_ID
     *
     * @param terminWyplatyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTerminWyplatyId(Long terminWyplatyId) {
        this.terminWyplatyId = terminWyplatyId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.KOD_SWIADCZENIA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKodSwiadczeniaId() {
        return kodSwiadczeniaId;
    }

    /**
     * POBIERANE_SWIADCZENIE.KOD_SWIADCZENIA_ID
     *
     * @param kodSwiadczeniaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodSwiadczeniaId(Long kodSwiadczeniaId) {
        this.kodSwiadczeniaId = kodSwiadczeniaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PobieraneSwiadczenie other = (PobieraneSwiadczenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSwiadczenieZmienioneId() == null ? other.getSwiadczenieZmienioneId() == null : this.getSwiadczenieZmienioneId().equals(other.getSwiadczenieZmienioneId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getDataZmiany() == null ? other.getDataZmiany() == null : this.getDataZmiany().equals(other.getDataZmiany()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getRodzajOdbioru() == null ? other.getRodzajOdbioru() == null : this.getRodzajOdbioru().equals(other.getRodzajOdbioru()))
            && (this.getInstytucjaDoplacajacaId() == null ? other.getInstytucjaDoplacajacaId() == null : this.getInstytucjaDoplacajacaId().equals(other.getInstytucjaDoplacajacaId()))
            && (this.getTerminWyplatyId() == null ? other.getTerminWyplatyId() == null : this.getTerminWyplatyId().equals(other.getTerminWyplatyId()))
            && (this.getKodSwiadczeniaId() == null ? other.getKodSwiadczeniaId() == null : this.getKodSwiadczeniaId().equals(other.getKodSwiadczeniaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSwiadczenieZmienioneId() == null) ? 0 : getSwiadczenieZmienioneId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getDataZmiany() == null) ? 0 : getDataZmiany().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getRodzajOdbioru() == null) ? 0 : getRodzajOdbioru().hashCode());
        result = prime * result + ((getInstytucjaDoplacajacaId() == null) ? 0 : getInstytucjaDoplacajacaId().hashCode());
        result = prime * result + ((getTerminWyplatyId() == null) ? 0 : getTerminWyplatyId().hashCode());
        result = prime * result + ((getKodSwiadczeniaId() == null) ? 0 : getKodSwiadczeniaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", swiadczenieZmienioneId=").append(swiadczenieZmienioneId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", dataZmiany=").append(dataZmiany);
        sb.append(", kwota=").append(kwota);
        sb.append(", nr=").append(nr);
        sb.append(", rodzajOdbioru=").append(rodzajOdbioru);
        sb.append(", instytucjaDoplacajacaId=").append(instytucjaDoplacajacaId);
        sb.append(", terminWyplatyId=").append(terminWyplatyId);
        sb.append(", kodSwiadczeniaId=").append(kodSwiadczeniaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PobieraneSwiadczenie.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.RodzajOdbioruSwiadczenia;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PobieraneSwiadczenie extends GenericDPSObject {
    /**
     * POBIERANE_SWIADCZENIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * POBIERANE_SWIADCZENIE.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * POBIERANE_SWIADCZENIE.SWIADCZENIE_ZMIENIONE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieZmienioneId;

    /**
     * POBIERANE_SWIADCZENIE.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * POBIERANE_SWIADCZENIE.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * POBIERANE_SWIADCZENIE.DATA_ZMIANY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataZmiany;

    /**
     * POBIERANE_SWIADCZENIE.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * POBIERANE_SWIADCZENIE.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * POBIERANE_SWIADCZENIE.RODZAJ_ODBIORU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajOdbioruSwiadczenia rodzajOdbioru;

    /**
     * POBIERANE_SWIADCZENIE.INSTYTUCJA_DOPLACAJACA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long instytucjaDoplacajacaId;

    /**
     * POBIERANE_SWIADCZENIE.TERMIN_WYPLATY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long terminWyplatyId;

    /**
     * POBIERANE_SWIADCZENIE.KOD_SWIADCZENIA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kodSwiadczeniaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POBIERANE_SWIADCZENIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POBIERANE_SWIADCZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * POBIERANE_SWIADCZENIE.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.SWIADCZENIE_ZMIENIONE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieZmienioneId() {
        return swiadczenieZmienioneId;
    }

    /**
     * POBIERANE_SWIADCZENIE.SWIADCZENIE_ZMIENIONE_ID
     *
     * @param swiadczenieZmienioneId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieZmienioneId(Long swiadczenieZmienioneId) {
        this.swiadczenieZmienioneId = swiadczenieZmienioneId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * POBIERANE_SWIADCZENIE.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * POBIERANE_SWIADCZENIE.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.DATA_ZMIANY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataZmiany() {
        return dataZmiany;
    }

    /**
     * POBIERANE_SWIADCZENIE.DATA_ZMIANY
     *
     * @param dataZmiany
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataZmiany(Date dataZmiany) {
        this.dataZmiany = dataZmiany;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * POBIERANE_SWIADCZENIE.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * POBIERANE_SWIADCZENIE.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return POBIERANE_SWIADCZENIE.RODZAJ_ODBIORU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajOdbioruSwiadczenia getRodzajOdbioru() {
        return rodzajOdbioru;
    }

    /**
     * POBIERANE_SWIADCZENIE.RODZAJ_ODBIORU
     *
     * @param rodzajOdbioru
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajOdbioru(RodzajOdbioruSwiadczenia rodzajOdbioru) {
        this.rodzajOdbioru = rodzajOdbioru;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.INSTYTUCJA_DOPLACAJACA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInstytucjaDoplacajacaId() {
        return instytucjaDoplacajacaId;
    }

    /**
     * POBIERANE_SWIADCZENIE.INSTYTUCJA_DOPLACAJACA_ID
     *
     * @param instytucjaDoplacajacaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInstytucjaDoplacajacaId(Long instytucjaDoplacajacaId) {
        this.instytucjaDoplacajacaId = instytucjaDoplacajacaId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.TERMIN_WYPLATY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getTerminWyplatyId() {
        return terminWyplatyId;
    }

    /**
     * POBIERANE_SWIADCZENIE.TERMIN_WYPLATY_ID
     *
     * @param terminWyplatyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTerminWyplatyId(Long terminWyplatyId) {
        this.terminWyplatyId = terminWyplatyId;
    }

    /**
     * @return POBIERANE_SWIADCZENIE.KOD_SWIADCZENIA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKodSwiadczeniaId() {
        return kodSwiadczeniaId;
    }

    /**
     * POBIERANE_SWIADCZENIE.KOD_SWIADCZENIA_ID
     *
     * @param kodSwiadczeniaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodSwiadczeniaId(Long kodSwiadczeniaId) {
        this.kodSwiadczeniaId = kodSwiadczeniaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PobieraneSwiadczenie other = (PobieraneSwiadczenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSwiadczenieZmienioneId() == null ? other.getSwiadczenieZmienioneId() == null : this.getSwiadczenieZmienioneId().equals(other.getSwiadczenieZmienioneId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getDataZmiany() == null ? other.getDataZmiany() == null : this.getDataZmiany().equals(other.getDataZmiany()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getRodzajOdbioru() == null ? other.getRodzajOdbioru() == null : this.getRodzajOdbioru().equals(other.getRodzajOdbioru()))
            && (this.getInstytucjaDoplacajacaId() == null ? other.getInstytucjaDoplacajacaId() == null : this.getInstytucjaDoplacajacaId().equals(other.getInstytucjaDoplacajacaId()))
            && (this.getTerminWyplatyId() == null ? other.getTerminWyplatyId() == null : this.getTerminWyplatyId().equals(other.getTerminWyplatyId()))
            && (this.getKodSwiadczeniaId() == null ? other.getKodSwiadczeniaId() == null : this.getKodSwiadczeniaId().equals(other.getKodSwiadczeniaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSwiadczenieZmienioneId() == null) ? 0 : getSwiadczenieZmienioneId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getDataZmiany() == null) ? 0 : getDataZmiany().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getRodzajOdbioru() == null) ? 0 : getRodzajOdbioru().hashCode());
        result = prime * result + ((getInstytucjaDoplacajacaId() == null) ? 0 : getInstytucjaDoplacajacaId().hashCode());
        result = prime * result + ((getTerminWyplatyId() == null) ? 0 : getTerminWyplatyId().hashCode());
        result = prime * result + ((getKodSwiadczeniaId() == null) ? 0 : getKodSwiadczeniaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", swiadczenieZmienioneId=").append(swiadczenieZmienioneId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", dataZmiany=").append(dataZmiany);
        sb.append(", kwota=").append(kwota);
        sb.append(", nr=").append(nr);
        sb.append(", rodzajOdbioru=").append(rodzajOdbioru);
        sb.append(", instytucjaDoplacajacaId=").append(instytucjaDoplacajacaId);
        sb.append(", terminWyplatyId=").append(terminWyplatyId);
        sb.append(", kodSwiadczeniaId=").append(kodSwiadczeniaId);
        sb.append("]");
        return sb.toString();
    }
}
